django-salesforce contributors
------------------------------
(ordered by first commit date)

* Phil Christensen <https://github.com/philchristensen>
* Steve Bussetti <https://github.com/sbussetti>
* Reggie Dugard <https://github.com/reggied>
* Hynek Cernoch <https://github.com/hynekcer>
* Bryan Alsdorf <https://github.com/balsdorf>
* Joshua Barone <https://github.com/jbarone>
* Benjamin Wohlwend <https://github.com/piquadrat>
* Jacob Wegner <https://github.com/jacobwegner>
* Jens Nistler <https://github.com/lociii>
* Ahmed Sa3d <https://github.com/zee93>
* Tobias Krönke <https://github.com/tuky>